@@ -43,11 +43,11 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   m_shareButton(NULL),
   m_commentButton(NULL),
   m_followButton(NULL),
-  m_followAuthorButton(NULL),
   m_deleteButton(NULL),
   m_object(NULL),
   m_actor(NULL),
   m_author(NULL),
+  m_activity(NULL),
   m_childWidget(childWidget)
 {
 #ifdef DEBUG_WIDGETS
@@ -59,7 +59,9 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   m_contentLayout = new QVBoxLayout;
   m_contentLayout->setContentsMargins(0, 0, 0, 0);
 
-  m_titleLabel = new QLabel(this); 
+  m_titleLabel = new RichTextLabel(this); 
+  connect(m_titleLabel, SIGNAL(linkHovered(const QString&)),
+          this,  SIGNAL(linkHovered(const QString&)));
   m_contentLayout->addWidget(m_titleLabel);
 
   m_imageLabel = new ImageLabel(this);
@@ -67,6 +69,11 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   m_imageLabel->setCursor(Qt::PointingHandCursor);
   m_contentLayout->addWidget(m_imageLabel);
 
+  m_streamLabel = new RichTextLabel(this);
+  connect(m_streamLabel, SIGNAL(linkHovered(const QString&)),
+          this,  SIGNAL(linkHovered(const QString&)));
+  m_contentLayout->addWidget(m_streamLabel, 0, Qt::AlignTop);
+
   m_textLabel = new RichTextLabel(this);
   connect(m_textLabel, SIGNAL(linkHovered(const QString&)),
           this,  SIGNAL(linkHovered(const QString&)));
@@ -115,11 +122,18 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   // If this object is not an actor itself, show the author in the
   // avatar image.
   m_actorWidget = new ActorWidget(NULL, this);
+  connect(m_actorWidget, SIGNAL(follow(QString, bool)),
+          this, SIGNAL(follow(QString, bool)));
+  connect(m_actorWidget, SIGNAL(lessClicked()), this, SIGNAL(lessClicked()));
+
+  m_lessButton = new TextToolButton("-", this);
+  connect(m_lessButton, SIGNAL(clicked()), this, SIGNAL(lessClicked()));
 
   QHBoxLayout* acrossLayout = new QHBoxLayout;
   acrossLayout->setSpacing(10);
   acrossLayout->addWidget(m_actorWidget, 0, Qt::AlignTop);
   acrossLayout->addLayout(rightLayout);
+  acrossLayout->addWidget(m_lessButton, 0, Qt::AlignTop);
 
   changeObject(obj);
   setSizePolicy(QSizePolicy::Ignored, QSizePolicy::MinimumExpanding);
@@ -140,9 +154,13 @@ FullObjectWidget::~FullObjectWidget() {
 void FullObjectWidget::changeObject(QASAbstractObject* obj) {
   if (m_object != NULL) {
     disconnect(m_object, SIGNAL(changed()), this, SLOT(onChanged()));
-    if (m_author)
+    if (m_author) {
+      disconnect(m_author, SIGNAL(changed()),
+                 m_actorWidget, SLOT(updateMenu()));
       disconnect(m_author, SIGNAL(changed()),
                  this, SLOT(updateFollowAuthorButton()));
+    }
+
     QASObjectList* ol = m_object->replies();
     if (ol)
       disconnect(ol, SIGNAL(changed()), this, SLOT(onChanged()));
@@ -158,11 +176,14 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
 
   connect(m_object, SIGNAL(changed()), this, SLOT(onChanged()));
 
-  if (objType == "comment") {
+  if (objType == "comment" || objType == "person") {
     setLineWidth(1);
     setFrameStyle(QFrame::StyledPanel | QFrame::Plain);
+    m_lessButton->setVisible(false);
   } else {
     setLineWidth(0);
+    setFrameStyle(QFrame::NoFrame | QFrame::Plain);
+    m_lessButton->setVisible(true);
   }
 
   if (!m_object->displayName().isEmpty()) {
@@ -180,27 +201,44 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
     m_imageLabel->setVisible(false);
   }
 
+  if (!m_object->streamUrl().isEmpty()) {
+    m_streamLabel->setVisible(true);
+    m_streamLabel->setText(QString("<b>Media:</b> <a href=\"%1\">%2</a>").
+                           arg(m_object->streamUrl(),
+                               m_object->type()));
+  } else if (objType == "file" && !m_object->fileUrl().isEmpty()) {
+    m_streamLabel->setVisible(true);
+    m_streamLabel->setText(QString("<b>File:</b> <a href=\"%1\">%2</a>").
+                           arg(m_object->fileUrl(),
+                               m_object->mimeType()));
+  } else {
+    m_streamLabel->setVisible(false);
+  }
+
   m_author = m_object->author();
-  if (m_author)
+  if (m_author) {
+    connect(m_author, SIGNAL(changed()),
+            m_actorWidget, SLOT(updateMenu()));
     connect(m_author, SIGNAL(changed()),
             this, SLOT(updateFollowAuthorButton()));
-
+  }
   // m_commentable = objType == "note" || objType == "comment" ||
   //   objType == "image" || objType == "video";
   m_commentable = objType != "person";
   if (m_commentable) {
     m_favourButton->setVisible(true);
-    m_followAuthorButton->setVisible(true);
     m_shareButton->setVisible(true);
     m_deleteButton->setVisible(m_author && m_author->isYou());
     m_commentButton->setVisible(true);
   } else {
     m_favourButton->setVisible(false);
-    m_followAuthorButton->setVisible(false);
     m_shareButton->setVisible(false);
     m_deleteButton->setVisible(false);
     m_commentButton->setVisible(false);
   }
+  
+  updateFollowAuthorButton();
+  //m_followAuthorButton->setVisible(m_commentable && notFollowingFOO);
 
   m_followButton->setVisible(objType == "person");
 
@@ -235,6 +273,7 @@ void FullObjectWidget::onChanged() {
                                hasValidIrtObject()));
   updateFollowButton();
   updateFollowAuthorButton();
+  m_actorWidget->updateMenu();
 
   QString text = m_object->content();
   if (m_actor) {
@@ -352,17 +391,14 @@ void FullObjectWidget::updateFollowAuthorButton(bool /*wait*/) {
   if (!m_followAuthorButton)
     return;
   
-  if (!m_author || !isFollowable(m_author)) {
+  if (!m_author || !isFollowable(m_author) || m_author->followed()) {
     m_followAuthorButton->setVisible(false);
     return;
   }
 
   m_followAuthorButton->setVisible(true);
 
-  QString text = (m_author->followed() ? tr("stop following") : tr("follow"))
-    + " ";
-  text += m_author->preferredUsername();
-
+  QString text = QString(tr("follow %1")).arg(m_author->preferredUsername());
   m_followAuthorButton->setText(text);
 }
 
@@ -372,7 +408,15 @@ void FullObjectWidget::updateImage() {
   FileDownloader* fd = FileDownloader::get(m_imageUrl, true);
   connect(fd, SIGNAL(fileReady()), this, SLOT(updateImage()),
           Qt::UniqueConnection);
-  m_imageLabel->setPixmap(fd->pixmap(":/images/broken_image.png"));
+
+  if (fd->ready() && fd->supportsAnimation()) {
+    QMovie* mov = fd->movie();
+    m_imageLabel->setMovie(mov);
+    qDebug() << "Animated GIF" << fd->fileName();
+    mov->start();
+  } else {
+    m_imageLabel->setPixmap(fd->pixmap(":/images/broken_image.png"));
+  }
 }    
 
 //------------------------------------------------------------------------------
@@ -537,7 +581,16 @@ void FullObjectWidget::favourite() {
 //------------------------------------------------------------------------------
 
 void FullObjectWidget::reply() {
-  emit newReply(m_object, NULL, NULL);
+  QASActivity* act = m_activity;
+  if (act == NULL) 
+    act = m_object->postingActivity();
+  if (act == NULL && hasValidIrtObject())
+    act = m_object->inReplyTo()->postingActivity();
+
+  QASObjectList* to = act && act->hasTo() ? act->to() : NULL;
+  QASObjectList* cc = act && act->hasCc() ? act->cc() : NULL;
+
+  emit newReply(m_object, to, cc);
 }
 
 //------------------------------------------------------------------------------
@@ -601,6 +654,7 @@ void FullObjectWidget::onRepeatClicked() {
 
 void FullObjectWidget::onFollow() {
   updateFollowButton(true);
+  updateFollowAuthorButton(true);
   if (isFollowable(m_actor))
     emit follow(m_actor->id(), !m_actor->followed());
 }
@@ -609,16 +663,10 @@ void FullObjectWidget::onFollow() {
 
 void FullObjectWidget::onFollowAuthor() {
   bool doFollow = !m_author->followed();
-  if (!doFollow) {
-    QString msg = tr("Are you sure you want to stop following") + " " +
-      m_author->displayNameOrWebFinger();
-    int ret = QMessageBox::warning(this, CLIENT_FANCY_NAME, msg,
-                                   QMessageBox::Cancel | QMessageBox::Yes,
-                                   QMessageBox::Cancel);
-    if (ret != QMessageBox::Yes)
-      return;
-  }
+  if (!doFollow)
+    return;
 
+  updateFollowButton(true);
   updateFollowAuthorButton(true);
   if (isFollowable(m_author))
     emit follow(m_author->id(), doFollow);
@@ -632,9 +680,10 @@ QString FullObjectWidget::processText(QString old_text, bool getImages) {
       << "br" << "p" << "b" << "i" << "blockquote" << "div" << "abbr"
       << "code" << "h1" << "h2" << "h3" << "h4" << "h5"
       << "em" << "ol" << "li" << "ul" << "hr" << "strong" << "u";
-    s_allowedTags << "pre";
+    s_allowedTags << "pre" << "s";
     s_allowedTags << "a";
     s_allowedTags << "img";
+    s_allowedTags << "table" << "tr" << "td" << "th" << "thead" << "tbody";
   }
   
   QString text = old_text.trimmed();
@@ -745,3 +794,9 @@ void FullObjectWidget::refreshTimeLabels() {
     }
   }
 }
+
+//------------------------------------------------------------------------------
+
+void FullObjectWidget::disableLessButton() {
+  m_lessButton->setVisible(false);
+}
